@@ -14,25 +14,17 @@ from .common import \
     without_return_value, \
     as_handler_invocation
 
-
-@dataclass
-class QueueEventStatus(InvocationStatus):
-    queue_name: 'str'
-
-
-@dataclass
-class IntegrationQueueStatus:
-    queues: 'Sequence[QueueEventStatus]'
+from .integration_deferral_queue import \
+    IntegrationDeferralQueue
 
 
 IntegrationQueueHandler = Callable[[Any], Awaitable[Sequence[Command]]]
 
-IntegrationQueueDict = Dict[str, Tuple[IntegrationQueueHandler, QueueEventStatus]]
+IntegrationQueueDict = Dict[str, Tuple[IntegrationQueueHandler, InvocationStatus]]
 
 class IntegrationQueueSinkImpl(IntegrationQueueSink):
 
-    def __init__(self,
-                 queues: IntegrationQueueDict):
+    def __init__(self, queues: IntegrationQueueDict):
         self.queues = queues
 
     async def put(self, message: 'Any', queue_name: 'str' = 'default'):
@@ -51,18 +43,17 @@ class IntegrationQueueSinkImpl(IntegrationQueueSink):
 
 class IntegrationQueueContext(IntegrationQueueEvents):
 
-    def __init__(self, client: 'AIOPartyClient'):
-        self.queue = \
-            asyncio.Queue(maxsize=1)  # type: asyncio.Queue[IntegrationQueueHandler]
+    def __init__(self, queue: 'IntegrationDeferralQueue', client: 'AIOPartyClient'):
+        self.queue = queue
         self.client = client
         self.queues = {}  # type: IntegrationQueueDict
         self.sink = IntegrationQueueSinkImpl(self.queues)
 
     def message(self, queue_name: 'str' = 'default'):
         def decorator(fn: 'IntegrationQueueHandler'):
-            status = QueueEventStatus(
+            status = InvocationStatus(
                 index=len(self.queues),
-                queue_name=queue_name,
+                label=queue_name,
                 command_count=0,
                 use_count=0,
                 error_count=0,
@@ -81,36 +72,12 @@ class IntegrationQueueContext(IntegrationQueueEvents):
                 async def doit():
                     await wrapped(message)
 
-                await self.queue.put(doit)
+                await self.queue.put(doit, status)
 
             self.queues[queue_name]=(enqueue_wrapped, status)
 
             return wrapped
         return decorator
 
-    async def worker(self):
-        LOG.debug('Queue context worker starting.')
-
-        while True:
-            LOG.debug('Waiting for queue event.')
-
-            try:
-                fn = await self.queue.get()
-                LOG.debug('Received queue event.')
-                commands = await fn()
-
-                if commands:
-                    LOG.info('Submitting queue event ledger commands: %r', commands)
-                    await self.client.submit(commands)
-
-            except:  # noqa: E722
-                LOG.exception('Uncaught error in queue context worker loop')
-
-    async def start(self):
-        worker_task = asyncio.create_task(self.worker())
-
-        asyncio.gather(worker_task)
-
-    def get_status(self) -> 'IntegrationQueueStatus':
-        return IntegrationQueueStatus(
-            queues=[status for (_, status) in self.queues.values()])
+    def get_status(self) -> 'Sequence[InvocationStatus]':
+        return [status for (_, status) in self.queues.values()]
