@@ -1,10 +1,12 @@
 from dataclasses import dataclass
-from typing import Optional, Sequence
+from typing import List, Optional, Sequence
 from functools import wraps
 
 from aiohttp import web
 from aiohttp.web import RouteTableDef
 
+from dazl import AIOPartyClient
+
 from .common import \
     InvocationStatus, \
     without_return_value, \
@@ -14,6 +16,8 @@ from ..api import IntegrationWebhookRoutes
 
 from .log import LOG
 
+from .integration_deferral_queue import \
+    IntegrationDeferralQueue
 
 def empty_success_response() -> 'web.HTTPOk':
     return web.HTTPOk()
@@ -23,17 +27,11 @@ def empty_success_response() -> 'web.HTTPOk':
 class WebhookRouteStatus(InvocationStatus):
     url_path: str
     method: str
-    label: 'Optional[str]'
-
-
-@dataclass
-class IntegrationWebhookStatus:
-    routes: 'Sequence[WebhookRouteStatus]'
 
 
 class IntegrationWebhookContext(IntegrationWebhookRoutes):
 
-    def __init__(self, client):
+    def __init__(self, queue: 'IntegrationDeferralQueue', client: 'AIOPartyClient'):
         self.route_table = RouteTableDef()
         self.client = client
 
@@ -103,6 +101,5 @@ class IntegrationWebhookContext(IntegrationWebhookRoutes):
 
         return wrap_method
 
-    def get_status(self) -> 'IntegrationWebhookStatus':
-        return IntegrationWebhookStatus(
-            routes=self.routes)
+    def get_status(self) -> 'Sequence[WebhookRouteStatus]':
+        return self.routes
